import { notify } from '../naiveDiscrete.js'

const DEFAULT_CONFIG = {
  successMessage: '操作成功', // 默认成功提示
  errorMessage: '操作失败', // 默认错误提示
  showSuccess: true, // 默认显示成功提示
  showError: true, // 默认显示错误提示
  timeout: 30000, // 默认超时时间（毫秒）
  throwOnError: true // 默认抛出错误
}

export const callPywebview = async (method, params = {}, config = {}) => {
  const mergedConfig = { ...DEFAULT_CONFIG, ...config }

  let timeoutId
  if (mergedConfig.timeout > 0) {
    timeoutId = setTimeout(() => {
      throw new Error(`调用 ${method} 超时`)
    }, mergedConfig.timeout)
  }

  try {
    if (!window.pywebview || !window.pywebview.api[method]) {
      throw new Error(`pywebview.api.${method} 方法不存在`)
    }

    const result = await window.pywebview.api[method](...Object.values(params))
    clearTimeout(timeoutId)

    if (mergedConfig.showSuccess) {
      notify.success(mergedConfig.successMessage)
    }
    if (mergedConfig.onSuccess) {
      mergedConfig.onSuccess(result)
    }

    return result
  } catch (error) {
    if (timeoutId) {
      clearTimeout(timeoutId)
    }

    if (mergedConfig.showError) {
      notify.error(mergedConfig.errorMessage)
    }
    if (mergedConfig.onError) {
      mergedConfig.onError(error)
    }
    if (mergedConfig.throwOnError) {
      throw error
    }

    return null
  }
}
